<?php

/**
 * index.php -- Displays the main frameset
 *
 * Copyright (c) 1999-2005 The SquirrelMail Project Team
 * Licensed under the GNU GPL. For full terms see the file COPYING.
 *
 * Redirects to the login page.
 *
 * $Id: index.php,v 1.14.2.3 2004/12/27 15:03:41 kink Exp $
 */

header('Location: src/login.php');

?>
<html></html>
